import base64
import secrets

from cryptography.fernet import Fernet
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC

KDF_ALGORITHM = hashes.SHA256()
KDF_LENGTH = 32
KDF_ITERATIONS = 120000


def encrypt(plaintext: str, password: str) -> (bytes, bytes):
    salt = secrets.token_bytes(16)
    kdf = PBKDF2HMAC(
        algorithm=KDF_ALGORITHM, length=KDF_LENGTH, salt=salt,
        iterations=KDF_ITERATIONS)
    key = kdf.derive(password.encode("utf-8"))

    # Encrypt the message.
    f = Fernet(base64.urlsafe_b64encode(key))
    ciphertext = f.encrypt(plaintext.encode("utf-8"))

    return ciphertext, salt



import argparse
import os

from banner import show_banner
from decryption import decrypt
from encryption import encrypt


def encrypt_file(file_path: str, password: str, extension: str):
    with open(file_path, "r", encoding='utf-8') as k:
        message = k.read()
    encrypted, salt = encrypt(message, password)
    encrypted_file_path = os.path.splitext(file_path)[0] + extension
    with open(encrypted_file_path, 'wb', encoding='utf-8') as e:
        e.write(salt)
        e.write(encrypted)
    print(
        f'[*] File Encryption Completed\n[*] File name: {encrypted_file_path}')


def decrypt_file(file_path: str, password: str, extension: str):
    with open(file_path, 'rb', encoding='utf-8') as d:
        salt = d.read(16)
        encrypted_message = d.read()
    try:
        decrypted = decrypt(encrypted_message, password, salt)
        decrypted_file_path = file_path
        with open(decrypted_file_path+extension, 'w', encoding='utf-8') as t:
            t.write(decrypted)
        print(f'File decrypted and saved as {decrypted_file_path}')
    except:
        print("Invalid Password")


def main():
    parser = argparse.ArgumentParser(
        description="ATENIGMA Basic File encryption and decryption with password")
    parser.add_argument('--file',
                        help='Path to the file to be processed')
    parser.add_argument('--key', help='Give your password')
    parser.add_argument('--encrypt', action='store_true',
                        help='Encrypt the file or data')
    parser.add_argument('--decrypt', action='store_true',
                        help='Decrypt the file or data')
    parser.add_argument('--showbanner', action='store_true',
                        help='Show the banner of the tool')
    parser.add_argument('--exten', default='.enc',
                        help='File extension for encrypted/decrypted files')

    args = parser.parse_args()
    file_path = args.file
    password = args.key

    if args.encrypt:
        encrypt_file(file_path, password, args.exten)
    elif args.decrypt:
        decrypt_file(file_path, password, args.exten)
    elif args.showbanner:
        show_banner()
    else:
        print("[!] No action selected (encrypt or decrypt)")


if __name__ == '__main__':
    main()



import os

from setuptools import find_packages, setup

with open('requirements.txt', 'r') as f:
    packages = f.read().splitlines()
    print(packages)


def read_file(filename):
    with open(os.path.join(os.path.dirname(__file__), filename)) as file:
        return file.read()


setup(
    name='ATENIGMA',
    version='0.0.2',
    author='Prasaanth',
    author_email='prasaanth2k@gmail.com',
    description='''
ATENIGMA is a versatile CLI utility that offers basic file encryption and decryption functionalities. This tool leverages the `cryptography` Python library to provide a user-friendly way to secure your files through AES encryption. With ATENIGMA, you can encrypt files with your custom password, adding an extra layer of protection to your sensitive data.
''',
    install_requires=packages,
    long_description=read_file('README.md'),
    long_description_content_type='text/markdown',
    entry_points={
        'console_scripts': [
            'atenigma=atenigma.banner:show_banner'
        ]

    }
)



import base64
import secrets

from cryptography.fernet import Fernet
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC

KDF_ALGORITHM = hashes.SHA256()
KDF_LENGTH = 32
KDF_ITERATIONS = 120000


def decrypt(ciphertext: bytes, password: str, salt: bytes) -> str:
    # Derive the symmetric key using the password and provided salt.
    kdf = PBKDF2HMAC(
        algorithm=KDF_ALGORITHM, length=KDF_LENGTH, salt=salt,
        iterations=KDF_ITERATIONS)
    key = kdf.derive(password.encode("utf-8"))

    # Decrypt the message.
    f = Fernet(base64.urlsafe_b64encode(key))
    plaintext = f.decrypt(ciphertext)

    return plaintext.decode("utf-8")
